@@ -42,7 +42,8 @@ class bigjob_coordination(object):
         
         self.address = "%s%s:%i"%(REDIS_URL_SCHEME, server, server_port)
         self.dbtype=""
-        self.redis_adaptor_start_time = datetime.datetime.utcnow().strftime("%s") 
+        #self.redis_adaptor_start_time = datetime.datetime.utcnow().strftime("%s") 
+        self.redis_adaptor_start_time = time.time()
         
         if server_connect_url!=None:
             self.address=server_connect_url    
@@ -78,9 +79,9 @@ class bigjob_coordination(object):
         self.pipe = self.redis_client.pipeline()
         try:
             self.redis_client.ping()
-        except:
-            logger.error("Please start Redis server!")
-            raise Exception("Please start Redis server!")
+        except Exception, ex:
+            logger.error("Cannot connect to Redis server: %s" % str(ex))
+            raise Exception("Cannot connect to Redis server: %s" % str(ex))
         
         
     def get_address(self):
@@ -204,15 +205,28 @@ class bigjob_coordination(object):
         self.redis_client.lpush(queue_name, job_url)
                 
         
-    def dequeue_job(self, pilot_url):
+    def dequeue_job(self, pilot_url, pilot_url2=None):
         """ deque to new job  of a certain pilot """
-        queue_name = pilot_url + ":queue"        
-        logger.debug("Dequeue sub-job from: " + queue_name 
-                      + " number queued items: " + str(self.redis_client.llen(queue_name)))
+        queue_list = []
+        queue_name = pilot_url + ":queue"
+        queue_list.append(queue_name)
+        if pilot_url2!=None:
+            queue_name2 = pilot_url2 + ":queue"        
+            queue_list.append(queue_name2)
+        logger.debug("Dequeue sub-job from: " + str(queue_list))
+        #+ " number queued items: " + str(self.redis_client.llen(queue_name)))
         #self.redis_client.set(queue_name + ':last_out', pickle.dumps(datetime.datetime.now()))
-        job_url = self.redis_client.brpop(queue_name, timeout=5)
+        job_url = self.redis_client.brpop(queue_list, timeout=1)
+        #job_url = self.redis_client.rpop(queue_name)
+        logger.debug("Dequeued: " + str(job_url))
         if job_url==None:
             return job_url
         logger.debug("Dequeued: " + str(job_url))
         return job_url[1]
     
+    
+    def get_queue_length(self, pilot_url):
+        queue_name = pilot_url + ":queue"        
+        length = self.redis_client.llen(queue_name)
+        logger.debug("Queue: " + queue_name  + " number queued items: " + str(length))        
+        return length
